<!--
id: care_vs_fairness
title: "Care vs Fairness"
category: care
-->

> "To comfort one may skew the scale,
> yet treat all right or hearts might fail.
> I pledge to blend both tender and rail,
> so equity and warmth prevail."
